pilas.habilidades.MoverseConElTeclado

Package pilas :: Module habilidades :: Class MoverseConElTeclado |
[hide private]
[frames] | no frames]

# Class MoverseConElTeclado

source code

    object --+
             |
     Habilidad --+
                 |
                MoverseConElTeclado

Known Subclasses:
  - MoverseComoCoche

Hace que un actor cambie de posición con pulsar el teclado.

Instance Methods | [hide private]
__init__(self, receptor, control=None, direcciones=8, velocidad_maxima=4, aceleracion=1, deceleracion=0.1, con_rotacion=False, velocidad_rotacion=1, marcha_atras=True) Inicializa la habilidad. | source code
set_velocidad_maxima(self, velocidad) | source code
get_velocidad_maxima(self) | source code
get_aceleracion(self) | source code
set_aceleracion(self, aceleracion) | source code
on_key_press(self, evento) | source code
decelerar(self) | source code
avanzar(self, delta) | source code
Inherited from `Habilidad`: `actualizar`, `eliminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| CUATRO_DIRECCIONES = `4`
| OCHO_DIRECCIONES = `8`

Properties | [hide private]
| velocidad_maxima Define la velocidad maxima.
| aceleracion Define la acelaracion.
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor, control=None, direcciones=8, velocidad_maxima=4, aceleracion=1, deceleracion=0.1, con_rotacion=False, velocidad_rotacion=1, marcha_atras=True) (Constructor) | source code
Inicializa la habilidad. :param receptor: Referencia al actor que aprenderá la habilidad. :param control: Control al que va a responder para mover el Actor. :param direcciones: Establece si puede mover en cualquier direccion o unicamente en 4 direcciones arriba, abajo, izquierda y derecha. El parametro con_rotacion establece las direcciones a OCHO_DIRECCIONES siempre. :param velocidad_maxima: Velocidad maxima en pixeles a la que se moverá el Actor. :param aceleracion: Indica lo rapido que acelera el actor hasta su velocidad máxima. :param deceleracion: Indica lo rapido que decelera el actor hasta parar. :param con_rotacion: Si deseas que el actor rote pulsando las teclas de izquierda y derecha. :param velocidad_rotacion: Indica lo rapido que rota un actor sobre si mismo. :param marcha_atras: Posibilidad de ir hacia atrás. (True o False) Overrides: object.__init__

Property Details | [hide private]

### velocidad_maxima Define la velocidad maxima. Get Method: get_velocidad_maxima(self) Set Method: set_velocidad_maxima(self, velocidad)

### aceleracion Define la acelaracion. Get Method: get_aceleracion(self) Set Method: set_aceleracion(self, aceleracion)